@@ -1,12 +1,20 @@
 /**
  * SECTION:object
+ * @title: GtkdocObject
  * @short_description: class for gtk-doc unit test
+ * @see_also: #GtkdocIface
+ * @Image: object.png
  *
  * This file contains non-sense code for the sole purpose of testing the docs.
  * We can link to the #GtkdocObject:otest property and the #GtkdocObject::otest
  * signal.
+ *
+ * When subclassing it is useful to override the #GtkdocObjectClass.test()
+ * method.
+ *
  * A new instance can be created using the gtkdoc_object_new() function. The
- * whole lifecycle usualy looks like shown in this example: |[
+ * whole lifecycle usualy looks like shown in this example:
+ * |[<!-- language="C" -->
  * GObject *myobj;
  * 
  * myobj = gtkdoc_object_new();
@@ -16,8 +24,18 @@
  *
  * You can also change parameters:
  * <informalexample>
- * <programlisting><xi:include xmlns:xi="http://www.w3.org/2003/XInclude" parse="text" href="../../examples/gobject.c" /></programlisting>
+ * <programlisting language="c"><xi:include xmlns:xi="http://www.w3.org/2003/XInclude" parse="text" href="../../examples/gobject.c" /></programlisting>
  * </informalexample>
+ *
+ * This example serves two main purposes:
+ * <itemizedlist>
+ * <listitem><para>
+ * testing conversion
+ * </para></listitem>
+ * <listitem><para>
+ * catching bugs
+ * </para></listitem>
+ * </itemizedlist>
  */
 
 #include <glib.h>
@@ -28,7 +46,8 @@
 /* property ids */
 
 enum {
-  GTKDOC_OBJECT_TEST=1
+  GTKDOC_OBJECT_TEST=1,
+  GTKDOC_OBJECT_DEP_TEST
 };
 
 /* constructor methods */
@@ -37,7 +56,9 @@ enum {
  * gtkdoc_object_new:
  *
  * Create a new instance
- *
+ * <note><para>
+ *   This will only work if you have called g_type_init() before.
+ * </para></note>
  * Returns: the instance or %NULL in case of an error
  *
  * Since: 0.1
@@ -46,10 +67,13 @@ GtkdocObject *gtkdoc_object_new (void) {
   return(NULL);
 }
 
+/* methods */
+
 /**
  * gtkdoc_object_set_otest:
  * @self: the object
- * @value: the new otest value
+ * @value: the new otest value, whose description extends further than one
+ *  line will allow
  *
  * Set the #GtkdocObject:otest property.
  *
@@ -66,14 +90,32 @@ void gtkdoc_object_set_otest (GObject *self, const gchar *value) {
  * @self: the object
  * @n: number of iterations
  *
- * Frobnicate the content of @self @n times.
+ * Frobnicate the content of @self @n times. This implements a
+ * complex algorithm (http://en.wikipedia.org/wiki/Algorithm).
+ * <footnote>
+ *  <para>
+ *    Negative frobnication can lead to unexpected behaviour.
+ *  </para>
+ * </footnote>
  *
  * Since: 0.5
  */
 void gtkdoc_object_frobnicate (GObject *self, gint n) {
   
 }
-/* methods */
+
+/**
+ * gtkdoc_object_fooify:
+ * @self: the object
+ * @...: a NULL terminated list of arguments
+ *
+ * Fooify the content of @self.
+ *
+ * Returns: %TRUE for success
+ */
+gboolean gtkdoc_object_fooify (GObject *self, ...) {
+  return TRUE;
+}
 
 /* class internals */
 
@@ -110,6 +152,28 @@ static void gtkdoc_object_class_init (GtkdocObjectClass *klass) {
                 G_TYPE_NONE, // return type
                 0); // n_params
 
+  /**
+   * GtkdocObject::dep-otest:
+   * @self: myself
+   *
+   * The event has been triggered.
+   *
+   * Deprecated: Use the #GtkdocObject::otest signal instead.
+   */
+  g_signal_new ("dep-otest", G_TYPE_FROM_CLASS (klass),
+                G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+                G_STRUCT_OFFSET (GtkdocObjectClass,test),
+                NULL, // accumulator
+                NULL, // acc data
+                g_cclosure_marshal_VOID__OBJECT,
+                G_TYPE_NONE, // return type
+                0); // n_params
+
+  /**
+   * GtkdocObject:otest:
+   *
+   * Since: 0.1
+   */
   g_object_class_install_property (gobject_class,GTKDOC_OBJECT_TEST,
                                   g_param_spec_string ("otest",
                                      "otest prop",
@@ -117,6 +181,17 @@ static void gtkdoc_object_class_init (GtkdocObjectClass *klass) {
                                      "dummy", /* default value */
                                      G_PARAM_READWRITE));
 
+  /**
+   * GtkdocObject:dep-otest:
+   *
+   * Deprecated: use #GtkdocObject:otest property
+   */
+  g_object_class_install_property (gobject_class,GTKDOC_OBJECT_DEP_TEST,
+                                  g_param_spec_string ("dep-otest",
+                                     "dep-otest prop",
+                                     "dummy deprecated property for object",
+                                     "dummy", /* default value */
+                                     G_PARAM_READWRITE));
 }
 
 GType gtkdoc_object_get_type (void) {
